==> freecad_0.11.4446-dfsg.orig.tar.gz: FreeCAD-0.11.4446/src/Mod/Raytracing/Gui/Resources/translations/Raytracing_zh.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS>
  <context>
    <name>CmdRaytracingExportProject</name>
    <message>
      <location/>
      <source>File</source>
      <translation>文件</translation>
    </message>
    <message>
      <location/>
      <source>&amp;Export project...</source>
      <translation>导出项目(&amp;E)...</translation>
    </message>
    <message>
      <location/>
      <source>Export the Povray project file</source>
      <translation>导出 Povray 项目文件</translation>
    </message>
  </context>
  <context>
    <name>CmdRaytracingNewPartSegment</name>
    <message>
      <location/>
      <source>Raytracing</source>
      <translation>光线追踪</translation>
    </message>
    <message>
      <location/>
      <source>Insert part</source>
      <translation>插入零件</translation>
    </message>
    <message>
      <location/>
      <source>Insert a new part object into a Povray project</source>
      <translation>插入一个新的零件对象到PovRay项目</translation>
    </message>
  </context>
  <context>
    <name>CmdRaytracingNewPovrayProject</name>
    <message>
      <location/>
      <source>Raytracing</source>
      <translation>光线追踪</translation>
    </message>
    <message>
      <location/>
      <source>New Povray project</source>
      <translation>新建 Povray 项目</translation>
    </message>
    <message>
      <location/>
      <source>Insert new Povray project into the document</source>
      <translation>在文档中插入新PovRay项目</translation>
    </message>
  </context>
  <context>
    <name>CmdRaytracingNewProject</name>
    <message>
      <location/>
      <source>Raytracing</source>
      <translation>光线追踪</translation>
    </message>
  </context>
  <context>
    <name>CmdRaytracingQuickRender</name>
    <message>
      <location/>
      <source>Raytracing</source>
      <translation>光线追踪</translation>
    </message>
  </context>
  <context>
    <name>CmdRaytracingWriteCamera</name>
    <message>
      <location/>
      <source>Raytracing</source>
      <translation>光线追踪</translation>
    </message>
    <message>
      <location/>
      <source>Export camera to povray</source>
      <translation>输出相机到PovRay文件</translation>
    </message>
    <message>
      <location/>
      <source>Export the camera positon of the active 3D view in PovRay format to a file</source>
      <translation>将PovRay格式中当前3d视图的相机位置输出到文件</translation>
    </message>
  </context>
  <context>
    <name>CmdRaytracingWritePart</name>
    <message>
      <location/>
      <source>Raytracing</source>
      <translation>光线追踪</translation>
    </message>
    <message>
      <location/>
      <source>Export part to povray...</source>
      <translation>输出零件到Povray...</translation>
    </message>
    <message>
      <location/>
      <source>Write the selected Part (object) as a povray file</source>
      <translation>将选中零件(对象)写入Povray文件</translation>
    </message>
  </context>
  <context>
    <name>CmdRaytracingWriteView</name>
    <message>
      <location/>
      <source>Raytracing</source>
      <translation>光线追踪</translation>
    </message>
    <message>
      <location/>
      <source>Export view to povray...</source>
      <translation>视图输出为Povray...</translation>
    </message>
    <message>
      <location/>
      <source>Write the active 3D view with camera and all its content to a povray file</source>
      <translation>将当前相机3D视图以及所有内容写入到Povray文件</translation>
    </message>
  </context>
  <context>
    <name>QObject</name>
    <message>
      <location/>
      <source>Povray(*.pov)</source>
      <translation>Povray(*.pov)</translation>
    </message>
    <message>
      <location/>
      <source>All Files (*.*)</source>
      <translation>所有文件(*.*)</translation>
    </message>
    <message>
      <location/>
      <source>Export page</source>
      <translation>导出页</translation>
    </message>
    <message>
      <location/>
      <source>Wrong selection</source>
      <translation>选择错误</translation>
    </message>
    <message>
      <location/>
      <source>Select a Part object.</source>
      <translation>选择零件对象.</translation>
    </message>
    <message>
      <location/>
      <source>No Povray project to insert</source>
      <translation>无Povray项目可插入</translation>
    </message>
    <message>
      <location/>
      <source>Create a Povray project to insert a view.</source>
      <translation>创建一个Povray项目以插入视图.</translation>
    </message>
    <message>
      <location/>
      <source>Select one Povray project object.</source>
      <translation>选择一个Povray项目.</translation>
    </message>
  </context>
  <context>
    <name>RaytracingGui::DlgSettingsRay</name>
    <message>
      <location/>
      <source>Raytracing</source>
      <translation>光线追踪</translation>
    </message>
    <message>
      <location/>
      <source>Directories</source>
      <translation>目录</translation>
    </message>
    <message>
      <location/>
      <source>Default Project dir:</source>
      <translation>默认项目路径:</translation>
    </message>
    <message>
      <location/>
      <source>Camera file name:</source>
      <translation>相机文件的名称:</translation>
    </message>
    <message>
      <location/>
      <source>Part file name:</source>
      <translation>零件文件名称:</translation>
    </message>
    <message>
      <location/>
      <source>TempCamera.inc</source>
      <translation>TempCamera.inc</translation>
    </message>
    <message>
      <location/>
      <source>TempPart.inc</source>
      <translation>TempPart.inc</translation>
    </message>
    <message>
      <location/>
      <source>Mesh export settings</source>
      <translation>网格导出设置</translation>
    </message>
    <message>
      <location/>
      <source>max mesh deviation:</source>
      <translation>最大网格偏差:</translation>
    </message>
    <message>
      <location/>
      <source>Do not calculate vertex normals</source>
      <translation>不计算顶点法线</translation>
    </message>
    <message>
      <location/>
      <source>Write u,v coordinates</source>
      <translation>写入U，V坐标</translation>
    </message>
  </context>
  <context>
    <name>RaytracingGui::Workbench</name>
    <message>
      <location/>
      <source>&amp;Raytracing</source>
      <translation>光线追踪(&amp;R)</translation>
    </message>
  </context>
</TS>

==> freecad_0.12.5284-dfsg.orig.tar.gz: FreeCAD-0.12.5284/src/Mod/Raytracing/Gui/Resources/translations/Raytracing_zh.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS>
  <context>
    <name>CmdRaytracingExportProject</name>
    <message>
      <location filename="../../Command.cpp" line="+452"/>
      <source>File</source>
      <translation>文件</translation>
    </message>
    <message>
      <source>&amp;Export project...</source>
      <translation>导出项目(&amp;E)...</translation>
    </message>
    <message>
      <source>Export the Povray project file</source>
      <translation>导出 Povray 项目文件</translation>
    </message>
  </context>
  <context>
    <name>CmdRaytracingNewPartSegment</name>
    <message>
      <source>Raytracing</source>
      <translation>光线追踪</translation>
    </message>
    <message>
      <source>Insert part</source>
      <translation>插入零件</translation>
    </message>
    <message>
      <source>Insert a new part object into a Povray project</source>
      <translation>插入一个新的零件对象到PovRay项目</translation>
    </message>
  </context>
  <context>
    <name>CmdRaytracingNewPovrayProject</name>
    <message>
      <source>Raytracing</source>
      <translation>光线追踪</translation>
    </message>
    <message>
      <source>New Povray project</source>
      <translation>新建 Povray 项目</translation>
    </message>
    <message>
      <source>Insert new Povray project into the document</source>
      <translation>在文档中插入新PovRay项目</translation>
    </message>
  </context>
  <context>
    <name>CmdRaytracingWriteCamera</name>
    <message>
      <source>Raytracing</source>
      <translation>光线追踪</translation>
    </message>
    <message>
      <source>Export camera to povray...</source>
      <translation>导出相机到povray...</translation>
    </message>
    <message>
      <source>Export the camera positon of the active 3D view in PovRay format to a file</source>
      <translation>将PovRay格式中当前3d视图的相机位置输出到文件</translation>
    </message>
  </context>
  <context>
    <name>CmdRaytracingWritePart</name>
    <message>
      <source>Raytracing</source>
      <translation>光线追踪</translation>
    </message>
    <message>
      <source>Export part to povray...</source>
      <translation>输出零件到Povray...</translation>
    </message>
    <message>
      <source>Write the selected Part (object) as a povray file</source>
      <translation>将选中零件(对象)写入Povray文件</translation>
    </message>
  </context>
  <context>
    <name>CmdRaytracingWriteView</name>
    <message>
      <source>Raytracing</source>
      <translation>光线追踪</translation>
    </message>
    <message>
      <source>Export view to povray...</source>
      <translation>视图输出为Povray...</translation>
    </message>
    <message>
      <source>Write the active 3D view with camera and all its content to a povray file</source>
      <translation>将当前相机3D视图以及所有内容写入到Povray文件</translation>
    </message>
  </context>
  <context>
    <name>QObject</name>
    <message>
      <source>Povray(*.pov)</source>
      <translation>Povray(*.pov)</translation>
    </message>
    <message>
      <source>All Files (*.*)</source>
      <translation>所有文件(*.*)</translation>
    </message>
    <message>
      <source>Export page</source>
      <translation>导出页面</translation>
    </message>
    <message>
      <source>Wrong selection</source>
      <translation>选择错误</translation>
    </message>
    <message>
      <source>Select a Part object.</source>
      <translation>选择零件对象.</translation>
    </message>
    <message>
      <source>No Povray project to insert</source>
      <translation>无Povray项目可插入</translation>
    </message>
    <message>
      <source>Create a Povray project to insert a view.</source>
      <translation>创建一个Povray项目以插入视图.</translation>
    </message>
    <message>
      <source>Select one Povray project object.</source>
      <translation>选择一个Povray项目.</translation>
    </message>
  </context>
  <context>
    <name>RaytracingGui::DlgSettingsRay</name>
    <message>
      <location filename="../../DlgSettingsRay.ui" line="+16"/>
      <source>Raytracing</source>
      <translation>光线追踪</translation>
    </message>
    <message>
      <source>Directories</source>
      <translation>目录</translation>
    </message>
    <message>
      <source>Default Project dir:</source>
      <translation>默认项目路径:</translation>
    </message>
    <message>
      <source>Camera file name:</source>
      <translation>相机文件的名称:</translation>
    </message>
    <message>
      <source>Part file name:</source>
      <translation>零件文件名称:</translation>
    </message>
    <message>
      <source>TempCamera.inc</source>
      <translation>TempCamera.inc</translation>
    </message>
    <message>
      <source>TempPart.inc</source>
      <translation>TempPart.inc</translation>
    </message>
    <message>
      <source>Mesh export settings</source>
      <translation>网格导出设置</translation>
    </message>
    <message>
      <source>max mesh deviation:</source>
      <translation>最大网格偏差:</translation>
    </message>
    <message>
      <source>Do not calculate vertex normals</source>
      <translation>不计算顶点法线</translation>
    </message>
    <message>
      <source>Write u,v coordinates</source>
      <translation>写入U，V坐标</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <location filename="../../Workbench.cpp" line="+37"/>
      <source>&amp;Raytracing</source>
      <translation>光线追踪(&amp;R)</translation>
    </message>
  </context>
</TS>
